==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/cn/hcn32.h <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
#if defined(CN72) && defined(_WIN32)
  #line 3 "d:\\v72\\sys\\src\\cn\\hcn32.h"
#endif 

/* @lastChanged: "1998-05-07  18:52"
 *
 * @filename:    hcn32.h
 * @purpose:     "backup history management"
 * @release:     7.1.0.0
 * @see:         "-.-"
 *
 * @copyright:   "Copyright by SAP AG, 1998"
 *
 * ==================================================================
 *
 * responsible:   Martin Reinecke (D024853 - Martin.Reinecke@SAP-AG.de)
 *
 * created:       1998-05-25 by Martin Reinecke
 *
 * purpose:       basic module for backup history
 *                               
 * ==================================================================
 */

#ifndef _HCN32_H_
#define _HCN32_H_

/* ------------------------------------------------------------------
 * includes
 * ------------------------------------------------------------------
 */
#include "gcn00.h"
#include "gcn003.h"

/* ------------------------------------------------------------------
 * specification public functions
 * ------------------------------------------------------------------
 */
tcn00_Error cn32BackupHistoryOpen (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryList (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryListNext (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryClose (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryDate (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32GetEBIDs(VControlDataT * vcontrol,
                         CommandT      * command,
                         char          * replyData,
                         int           * replyLen,
                         int             replyLenMax);

tcn00_Error cn32ListNextEBIDs(VControlDataT * vcontrol,
                              CommandT      * command,
                              char          * replyData,
                              int           * replyLen,
                              int             replyLenMax);

tcn00_Error cn32ForgetEBIDs(VControlDataT * vcontrol,
                            CommandT      * command,
                            char          * replyData,
                            int           * replyLen,
                            int             replyLenMax);

void cn32FreeHistorySession(VControlDataT * vcontrol);
void cn32FreeEBIDList(VControlDataT * vcontrol);

#endif /* _HCN32_H_ */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/cn/hcn32.h <==
/*! 
  -----------------------------------------------------------------------------
 
  module: hcn40.h
 
  -----------------------------------------------------------------------------
 
  responsible:  Martin Reinecke (D024853 - Martin.Reinecke@SAP-AG.de)
  
  description:  basic module for backup history

  copyright:    by SAP AG, 2000

  -----------------------------------------------------------------------------

    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end
 
  -----------------------------------------------------------------------------
*/

#ifndef _HCN32_H_
#define _HCN32_H_

/* ------------------------------------------------------------------
 * includes
 * ------------------------------------------------------------------
 */
#include "gcn00.h"
#include "gcn003.h"

/* ------------------------------------------------------------------
 * specification public functions
 * ------------------------------------------------------------------
 */
tcn00_Error cn32BackupHistoryOpen (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryList (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryListNext (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryClose (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32BackupHistoryDate (
      VControlDataT * vcontrol,
      CommandT      * command,
      char          * replyData,
      int           * replyLen,
      int             replyLenMax );

tcn00_Error cn32GetEBIDs(VControlDataT * vcontrol,
                         CommandT      * command,
                         char          * replyData,
                         int           * replyLen,
                         int             replyLenMax);

tcn00_Error cn32ListNextEBIDs(VControlDataT * vcontrol,
                              CommandT      * command,
                              char          * replyData,
                              int           * replyLen,
                              int             replyLenMax);

tcn00_Error cn32ForgetEBIDs(VControlDataT * vcontrol,
                            CommandT      * command,
                            char          * replyData,
                            int           * replyLen,
                            int             replyLenMax);

void cn32FreeHistorySession(VControlDataT * vcontrol);
void cn32FreeEBIDList(VControlDataT * vcontrol);

tcn00_Error cn32AnalyzeLogBackup(tcn003_BackupResult * tResult);

#endif /* _HCN32_H_ */
